@@ -12,16 +12,20 @@ class BaseRepository(implements(InterfaceBaseRepository)):
 
     def execute_query(
             self,
-            query: Query,
+            query: Query | T,
     ) -> list[T]:
         """
         Выполнение запроса
         """
-        items: T = query.firebase_query.get()
-        return [
-            self.model(id=item.id, **item._data)
-            for item in items
-        ]
+        if isinstance(query, Query):
+            items: T = query.firebase_query.get()
+            return [
+                self.model(id=item.id, **item._data)
+                for item in items
+            ]
+        else:
+            item: T = query
+            return self.model(id=item.id, **item._data)
 
     def get_by_id(
             self,
