@@ -11,6 +11,12 @@ class InterfaceBaseRepository(Interface):
     ) -> list[T]:
         pass
 
+    def get_by_id(
+            self,
+            item_id: str
+    ) -> Query:
+        pass
+
     def get_by_field(
             self,
             field: str,
